{% load i18n %}

{% if enable_admin_shortcuts %}
	{% if admin_shortcuts %}
		<ul class="shortcuts">
		{% for group in admin_shortcuts %}
			{% if group.title %}<h2>{{ group.title }}</h2>{% endif %}
			<ul>
			{% for shortcut in group.shortcuts %}
				<li>{% include 'admin_shortcuts/shortcut.html' %}</li>
			{% endfor %}
			</ul>
		{% endfor %}
		</ul>
	{% endif %}
{% endif %}