{% extends 'admin_shortcuts/base.css' %}
{% load static admin_shortcuts_tags %}

{% block main %}
/* shortcuts */
.admin_shortcuts .shortcuts {
    padding: 10px 40px 10px 40px;
    margin: 0;
    list-style: none;
}

@media (max-width: 1024px) {
    .admin_shortcuts .shortcuts {
        padding-left: 20px;
        padding-right: 20px;
    }
}

.admin_shortcuts .shortcuts ul:after {
    content: ".";
    display: block;
    clear: both;
    visibility: hidden;
    line-height: 0;
    height: 0;
}

.admin_shortcuts .shortcuts ul {
    padding: 0;
    margin: 5px 0 0 0;
    list-style: none;
}

.admin_shortcuts .shortcuts h2 {
	font-weight: normal;
    color: #666;
    line-height: 24px;
    margin: 10px 0 5px;
}

.admin_shortcuts .shortcuts li {
    padding: 0;
    margin: 0;
    float: left;
    list-style: none;
}

.admin_shortcuts .shortcuts li a {
    padding: 20px 0px 20px 55px;
    margin: 5px 10px 5px 0;
    display: block;
    float: left;
    color: #666;
    border: 1px solid #ddd;
    background: #fff;
    font-size: 14px;
    line-height: 14px;
    border-radius: 4px;
    position: relative;
    min-height: 14px;
	transition: none;
}

.admin_shortcuts .shortcuts li a .title {
    padding-right: 25px;
}

.admin_shortcuts .shortcuts li a:hover, .admin_shortcuts .shortcuts li a:focus, .admin_shortcuts .shortcuts li a:active {
    border-color: #888;
	color: #333;
    text-decoration: none;
}
{% endblock %}


{% block count %}
/* count */
.admin_shortcuts .shortcuts li a .count {
    position: absolute;
    right: 3px;
    bottom: 2px;
    color: #aaa;
    font-size: 10px;
}

.admin_shortcuts .shortcuts li a .count_new {
    position: absolute;
    right: -7px;
    top: -7px;
    color: #fff;
    font-size: 11px;
    line-height: 14px;
    border-radius: 30px;
    display: block;
    overflow: hidden;
    max-width: 60px;
    min-width: 15px;
    height: 20px;
    padding: 5px 5px 0 5px;
    background: #940f3a;
    text-align: center;
    font-weight: bold;
}
{% endblock %}


{% block icons %}
/* icons */
.admin_shortcuts .shortcuts li a .icon {
    width: 34px;
    height: 32px;
    text-align: center;
    font-size: 24px;
    line-height: 32px;
    position: absolute;
    left: 10px;
    top: 10px;
}
{% endblock %}


{% block dark_mode %}
@media (prefers-color-scheme: dark) {
	.admin_shortcuts .shortcuts li a {
		background: #333;
		color: #ccc;
		border-color: #444;
	}
	.admin_shortcuts .shortcuts li a:hover, .admin_shortcuts .shortcuts li a:focus, .admin_shortcuts .shortcuts li a:active {
		border-color: #888;
		color: #fff;
	}
}
@media (prefers-color-scheme: light) {
	.admin_shortcuts .shortcuts li a {
		background: #fff;
		color: #666;
		border-color: #ddd;
	}
	.admin_shortcuts .shortcuts li a:hover, .admin_shortcuts .shortcuts li a:focus, .admin_shortcuts .shortcuts li a:active {
		border-color: #888;
		color: #333;
	}
}
html[data-theme="dark"] {
	.admin_shortcuts .shortcuts li a {
		background: #333;
		color: #ccc;
		border-color: #444;
	}
	.admin_shortcuts .shortcuts li a:hover, .admin_shortcuts .shortcuts li a:focus, .admin_shortcuts .shortcuts li a:active {
		border-color: #888;
		color: #fff;
	}
}
html[data-theme="light"] {
	.admin_shortcuts .shortcuts li a {
		background: #fff;
		color: #666;
		border-color: #ddd;
	}
	.admin_shortcuts .shortcuts li a:hover, .admin_shortcuts .shortcuts li a:focus, .admin_shortcuts .shortcuts li a:active {
		border-color: #888;
		color: #333;
	}
}
{% endblock %}
